summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/imagedev/floppy.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/imagedev/floppy.cpp')
-rw-r--r--src/devices/imagedev/floppy.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/imagedev/floppy.cpp b/src/devices/imagedev/floppy.cpp
index f725845fa0d..3dd96644f1a 100644
--- a/src/devices/imagedev/floppy.cpp
+++ b/src/devices/imagedev/floppy.cpp
@@ -1248,7 +1248,7 @@ void floppy_sound_device::device_start()
// If we don't have all samples, don't allocate a stream or access sample data.
if (m_loaded)
{
- m_sound = machine().sound().stream_alloc(*this, 0, 1, clock()); // per-floppy stream
+ m_sound = stream_alloc_legacy(0, 1, clock()); // per-floppy stream
}
register_for_save_states();
}
@@ -1369,10 +1369,10 @@ void floppy_sound_device::step(int zone)
}
//-------------------------------------------------
// sound_stream_update - update the sound stream
//-------------------------------------------------
-void floppy_sound_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void floppy_sound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
// We are using only one stream, unlike the parent class
// Also, there is no need for interpolation, as we only expect
@@ -1369,10 +1369,10 @@ void floppy_sound_device::step(int zone)
}
//-------------------------------------------------
-// sound_stream_update - update the sound stream
+// sound_stream_update_legacy - update the sound stream
//-------------------------------------------------